import React, { HTMLAttributes } from 'react';
import Chart from 'chart.js/auto';
export interface CChartProps extends HTMLAttributes<HTMLCanvasElement | HTMLDivElement> {
    /**
     * A string of all className you want applied to the base component.
     */
    className?: string;
    /**
     * Enables custom html based tooltips instead of standard tooltips.
     *
     * @default true
     */
    customTooltips?: boolean;
    /**
     * The data object that is passed into the Chart.js chart (more info).
     */
    data: Chart.ChartData | ((canvas: HTMLCanvasElement) => Chart.ChartData);
    /**
     * A fallback for when the canvas cannot be rendered. Can be used for accessible chart descriptions.
     *
     * {@link https://www.chartjs.org/docs/latest/general/accessibility.html More Info}
     */
    fallbackContent?: React.ReactNode;
    /**
     * Proxy for Chart.js getDatasetAtEvent. Calls with dataset and triggering event.
     */
    getDatasetAtEvent?: (dataset: Array<{}>, event: React.MouseEvent<HTMLCanvasElement>) => void;
    /**
     * Proxy for Chart.js getElementAtEvent. Calls with single element array and triggering event.
     */
    getElementAtEvent?: (element: [{}], event: React.MouseEvent<HTMLCanvasElement>) => void;
    /**
     * Proxy for Chart.js getElementsAtEvent. Calls with element array and triggering event.
     */
    getElementsAtEvent?: (elements: Array<{}>, event: React.MouseEvent<HTMLCanvasElement>) => void;
    /**
     * Height attribute applied to the rendered canvas.
     *
     * @default 150
     */
    height?: number;
    /**
     * ID attribute applied to the rendered canvas.
     */
    id?: string;
    /**
     * The options object that is passed into the Chart.js chart.
     *
     * {@link https://www.chartjs.org/docs/latest/general/options.html More Info}
     */
    options?: Chart.ChartOptions;
    /**
     * The plugins array that is passed into the Chart.js chart (more info)
     *
     * {@link https://www.chartjs.org/docs/latest/developers/plugins.html More Info}
     */
    plugins?: Chart.PluginServiceRegistrationOptions[];
    /**
     * If true, will tear down and redraw chart on all updates.
     *
     * @default false
     */
    redraw?: boolean;
    /**
     * Chart.js chart type.
     *
     * @type {'line' | 'bar' | 'horizontalBar' | 'radar' | 'doughnut' | 'polarArea' | 'bubble' | 'pie' | 'scatter'}
     */
    type: Chart.ChartType;
    /**
     * Width attribute applied to the rendered canvas.
     *
     * @default 300
     */
    width?: number;
    /**
     * Put the chart into the wrapper div element.
     *
     * @default true
     */
    wrapper?: boolean;
}
export declare const CChart: React.ForwardRefExoticComponent<CChartProps & React.RefAttributes<any>>;
